# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AppsPosBody(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'app_name': 'str',
        'title': 'str',
        'description': 'str',
        'template': 'str',
        'default_view': 'str',
        'currency': 'str',
        'show_custom_amount': 'bool',
        'show_discount': 'bool',
        'enable_tips': 'bool',
        'custom_amount_pay_button_text': 'str',
        'fixed_amount_pay_button_text': 'str',
        'tip_text': 'str',
        'custom_css_link': 'str',
        'embedded_css': 'str',
        'notification_url': 'str',
        'redirect_url': 'str',
        'redirect_automatically': 'bool',
        'requires_refund_email': 'bool'
    }

    attribute_map = {
        'app_name': 'appName',
        'title': 'title',
        'description': 'description',
        'template': 'template',
        'default_view': 'defaultView',
        'currency': 'currency',
        'show_custom_amount': 'showCustomAmount',
        'show_discount': 'showDiscount',
        'enable_tips': 'enableTips',
        'custom_amount_pay_button_text': 'customAmountPayButtonText',
        'fixed_amount_pay_button_text': 'fixedAmountPayButtonText',
        'tip_text': 'tipText',
        'custom_css_link': 'customCSSLink',
        'embedded_css': 'embeddedCSS',
        'notification_url': 'notificationUrl',
        'redirect_url': 'redirectUrl',
        'redirect_automatically': 'redirectAutomatically',
        'requires_refund_email': 'requiresRefundEmail'
    }

    def __init__(self, app_name=None, title=None, description=None, template=None, default_view=None, currency=None, show_custom_amount=True, show_discount=True, enable_tips=True, custom_amount_pay_button_text='Pay', fixed_amount_pay_button_text='Buy for {PRICE_HERE}', tip_text='Do you want to leave a tip?', custom_css_link=None, embedded_css=None, notification_url=None, redirect_url=None, redirect_automatically=None, requires_refund_email=None):  # noqa: E501
        """AppsPosBody - a model defined in Swagger"""  # noqa: E501
        self._app_name = None
        self._title = None
        self._description = None
        self._template = None
        self._default_view = None
        self._currency = None
        self._show_custom_amount = None
        self._show_discount = None
        self._enable_tips = None
        self._custom_amount_pay_button_text = None
        self._fixed_amount_pay_button_text = None
        self._tip_text = None
        self._custom_css_link = None
        self._embedded_css = None
        self._notification_url = None
        self._redirect_url = None
        self._redirect_automatically = None
        self._requires_refund_email = None
        self.discriminator = None
        if app_name is not None:
            self.app_name = app_name
        if title is not None:
            self.title = title
        if description is not None:
            self.description = description
        if template is not None:
            self.template = template
        if default_view is not None:
            self.default_view = default_view
        if currency is not None:
            self.currency = currency
        if show_custom_amount is not None:
            self.show_custom_amount = show_custom_amount
        if show_discount is not None:
            self.show_discount = show_discount
        if enable_tips is not None:
            self.enable_tips = enable_tips
        if custom_amount_pay_button_text is not None:
            self.custom_amount_pay_button_text = custom_amount_pay_button_text
        if fixed_amount_pay_button_text is not None:
            self.fixed_amount_pay_button_text = fixed_amount_pay_button_text
        if tip_text is not None:
            self.tip_text = tip_text
        if custom_css_link is not None:
            self.custom_css_link = custom_css_link
        if embedded_css is not None:
            self.embedded_css = embedded_css
        if notification_url is not None:
            self.notification_url = notification_url
        if redirect_url is not None:
            self.redirect_url = redirect_url
        if redirect_automatically is not None:
            self.redirect_automatically = redirect_automatically
        if requires_refund_email is not None:
            self.requires_refund_email = requires_refund_email

    @property
    def app_name(self):
        """Gets the app_name of this AppsPosBody.  # noqa: E501

        The name of the app (shown in admin UI)  # noqa: E501

        :return: The app_name of this AppsPosBody.  # noqa: E501
        :rtype: str
        """
        return self._app_name

    @app_name.setter
    def app_name(self, app_name):
        """Sets the app_name of this AppsPosBody.

        The name of the app (shown in admin UI)  # noqa: E501

        :param app_name: The app_name of this AppsPosBody.  # noqa: E501
        :type: str
        """

        self._app_name = app_name

    @property
    def title(self):
        """Gets the title of this AppsPosBody.  # noqa: E501

        The title of the app (shown to the user)  # noqa: E501

        :return: The title of this AppsPosBody.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this AppsPosBody.

        The title of the app (shown to the user)  # noqa: E501

        :param title: The title of this AppsPosBody.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def description(self):
        """Gets the description of this AppsPosBody.  # noqa: E501

        The description of the app  # noqa: E501

        :return: The description of this AppsPosBody.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this AppsPosBody.

        The description of the app  # noqa: E501

        :param description: The description of this AppsPosBody.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def template(self):
        """Gets the template of this AppsPosBody.  # noqa: E501

        Template for items available in the app  # noqa: E501

        :return: The template of this AppsPosBody.  # noqa: E501
        :rtype: str
        """
        return self._template

    @template.setter
    def template(self, template):
        """Sets the template of this AppsPosBody.

        Template for items available in the app  # noqa: E501

        :param template: The template of this AppsPosBody.  # noqa: E501
        :type: str
        """

        self._template = template

    @property
    def default_view(self):
        """Gets the default_view of this AppsPosBody.  # noqa: E501

        Template for items available in the app  # noqa: E501

        :return: The default_view of this AppsPosBody.  # noqa: E501
        :rtype: str
        """
        return self._default_view

    @default_view.setter
    def default_view(self, default_view):
        """Sets the default_view of this AppsPosBody.

        Template for items available in the app  # noqa: E501

        :param default_view: The default_view of this AppsPosBody.  # noqa: E501
        :type: str
        """
        allowed_values = ["Static", "Cart", "Light", "Print"]  # noqa: E501
        if default_view not in allowed_values:
            raise ValueError(
                "Invalid value for `default_view` ({0}), must be one of {1}"  # noqa: E501
                .format(default_view, allowed_values)
            )

        self._default_view = default_view

    @property
    def currency(self):
        """Gets the currency of this AppsPosBody.  # noqa: E501

        Currency to use for the app. Defaults to the currency used by the store if not specified  # noqa: E501

        :return: The currency of this AppsPosBody.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this AppsPosBody.

        Currency to use for the app. Defaults to the currency used by the store if not specified  # noqa: E501

        :param currency: The currency of this AppsPosBody.  # noqa: E501
        :type: str
        """

        self._currency = currency

    @property
    def show_custom_amount(self):
        """Gets the show_custom_amount of this AppsPosBody.  # noqa: E501

        Whether to include a special item in the store which allows user to input a custom payment amount  # noqa: E501

        :return: The show_custom_amount of this AppsPosBody.  # noqa: E501
        :rtype: bool
        """
        return self._show_custom_amount

    @show_custom_amount.setter
    def show_custom_amount(self, show_custom_amount):
        """Sets the show_custom_amount of this AppsPosBody.

        Whether to include a special item in the store which allows user to input a custom payment amount  # noqa: E501

        :param show_custom_amount: The show_custom_amount of this AppsPosBody.  # noqa: E501
        :type: bool
        """

        self._show_custom_amount = show_custom_amount

    @property
    def show_discount(self):
        """Gets the show_discount of this AppsPosBody.  # noqa: E501

        Whether to allow user to input a discount amount. Applies to Cart view only. Not recommended for customer self-checkout  # noqa: E501

        :return: The show_discount of this AppsPosBody.  # noqa: E501
        :rtype: bool
        """
        return self._show_discount

    @show_discount.setter
    def show_discount(self, show_discount):
        """Sets the show_discount of this AppsPosBody.

        Whether to allow user to input a discount amount. Applies to Cart view only. Not recommended for customer self-checkout  # noqa: E501

        :param show_discount: The show_discount of this AppsPosBody.  # noqa: E501
        :type: bool
        """

        self._show_discount = show_discount

    @property
    def enable_tips(self):
        """Gets the enable_tips of this AppsPosBody.  # noqa: E501

        Whether to allow user to input a tip amount. Applies to Cart and Light views only  # noqa: E501

        :return: The enable_tips of this AppsPosBody.  # noqa: E501
        :rtype: bool
        """
        return self._enable_tips

    @enable_tips.setter
    def enable_tips(self, enable_tips):
        """Sets the enable_tips of this AppsPosBody.

        Whether to allow user to input a tip amount. Applies to Cart and Light views only  # noqa: E501

        :param enable_tips: The enable_tips of this AppsPosBody.  # noqa: E501
        :type: bool
        """

        self._enable_tips = enable_tips

    @property
    def custom_amount_pay_button_text(self):
        """Gets the custom_amount_pay_button_text of this AppsPosBody.  # noqa: E501

        Payment button text which appears for items which allow user to input a custom amount  # noqa: E501

        :return: The custom_amount_pay_button_text of this AppsPosBody.  # noqa: E501
        :rtype: str
        """
        return self._custom_amount_pay_button_text

    @custom_amount_pay_button_text.setter
    def custom_amount_pay_button_text(self, custom_amount_pay_button_text):
        """Sets the custom_amount_pay_button_text of this AppsPosBody.

        Payment button text which appears for items which allow user to input a custom amount  # noqa: E501

        :param custom_amount_pay_button_text: The custom_amount_pay_button_text of this AppsPosBody.  # noqa: E501
        :type: str
        """

        self._custom_amount_pay_button_text = custom_amount_pay_button_text

    @property
    def fixed_amount_pay_button_text(self):
        """Gets the fixed_amount_pay_button_text of this AppsPosBody.  # noqa: E501

        Payment button text which appears for items which have a fixed price  # noqa: E501

        :return: The fixed_amount_pay_button_text of this AppsPosBody.  # noqa: E501
        :rtype: str
        """
        return self._fixed_amount_pay_button_text

    @fixed_amount_pay_button_text.setter
    def fixed_amount_pay_button_text(self, fixed_amount_pay_button_text):
        """Sets the fixed_amount_pay_button_text of this AppsPosBody.

        Payment button text which appears for items which have a fixed price  # noqa: E501

        :param fixed_amount_pay_button_text: The fixed_amount_pay_button_text of this AppsPosBody.  # noqa: E501
        :type: str
        """

        self._fixed_amount_pay_button_text = fixed_amount_pay_button_text

    @property
    def tip_text(self):
        """Gets the tip_text of this AppsPosBody.  # noqa: E501

        Prompt which appears next to the tip amount field if tipping is enabled  # noqa: E501

        :return: The tip_text of this AppsPosBody.  # noqa: E501
        :rtype: str
        """
        return self._tip_text

    @tip_text.setter
    def tip_text(self, tip_text):
        """Sets the tip_text of this AppsPosBody.

        Prompt which appears next to the tip amount field if tipping is enabled  # noqa: E501

        :param tip_text: The tip_text of this AppsPosBody.  # noqa: E501
        :type: str
        """

        self._tip_text = tip_text

    @property
    def custom_css_link(self):
        """Gets the custom_css_link of this AppsPosBody.  # noqa: E501

        Link to a custom CSS stylesheet to be used in the app  # noqa: E501

        :return: The custom_css_link of this AppsPosBody.  # noqa: E501
        :rtype: str
        """
        return self._custom_css_link

    @custom_css_link.setter
    def custom_css_link(self, custom_css_link):
        """Sets the custom_css_link of this AppsPosBody.

        Link to a custom CSS stylesheet to be used in the app  # noqa: E501

        :param custom_css_link: The custom_css_link of this AppsPosBody.  # noqa: E501
        :type: str
        """

        self._custom_css_link = custom_css_link

    @property
    def embedded_css(self):
        """Gets the embedded_css of this AppsPosBody.  # noqa: E501

        Custom CSS to embed into the app  # noqa: E501

        :return: The embedded_css of this AppsPosBody.  # noqa: E501
        :rtype: str
        """
        return self._embedded_css

    @embedded_css.setter
    def embedded_css(self, embedded_css):
        """Sets the embedded_css of this AppsPosBody.

        Custom CSS to embed into the app  # noqa: E501

        :param embedded_css: The embedded_css of this AppsPosBody.  # noqa: E501
        :type: str
        """

        self._embedded_css = embedded_css

    @property
    def notification_url(self):
        """Gets the notification_url of this AppsPosBody.  # noqa: E501

        Callback notification url to POST to once when invoice is paid for and once when there are enough blockchain confirmations  # noqa: E501

        :return: The notification_url of this AppsPosBody.  # noqa: E501
        :rtype: str
        """
        return self._notification_url

    @notification_url.setter
    def notification_url(self, notification_url):
        """Sets the notification_url of this AppsPosBody.

        Callback notification url to POST to once when invoice is paid for and once when there are enough blockchain confirmations  # noqa: E501

        :param notification_url: The notification_url of this AppsPosBody.  # noqa: E501
        :type: str
        """

        self._notification_url = notification_url

    @property
    def redirect_url(self):
        """Gets the redirect_url of this AppsPosBody.  # noqa: E501

        URL to redirect user to once invoice is paid  # noqa: E501

        :return: The redirect_url of this AppsPosBody.  # noqa: E501
        :rtype: str
        """
        return self._redirect_url

    @redirect_url.setter
    def redirect_url(self, redirect_url):
        """Sets the redirect_url of this AppsPosBody.

        URL to redirect user to once invoice is paid  # noqa: E501

        :param redirect_url: The redirect_url of this AppsPosBody.  # noqa: E501
        :type: str
        """

        self._redirect_url = redirect_url

    @property
    def redirect_automatically(self):
        """Gets the redirect_automatically of this AppsPosBody.  # noqa: E501

        Whether to redirect user to redirect URL automatically once invoice is paid. Defaults to what is set in the store settings  # noqa: E501

        :return: The redirect_automatically of this AppsPosBody.  # noqa: E501
        :rtype: bool
        """
        return self._redirect_automatically

    @redirect_automatically.setter
    def redirect_automatically(self, redirect_automatically):
        """Sets the redirect_automatically of this AppsPosBody.

        Whether to redirect user to redirect URL automatically once invoice is paid. Defaults to what is set in the store settings  # noqa: E501

        :param redirect_automatically: The redirect_automatically of this AppsPosBody.  # noqa: E501
        :type: bool
        """

        self._redirect_automatically = redirect_automatically

    @property
    def requires_refund_email(self):
        """Gets the requires_refund_email of this AppsPosBody.  # noqa: E501

        Whether to redirect user to redirect URL automatically once invoice is paid. Defaults to what is set in the store settings  # noqa: E501

        :return: The requires_refund_email of this AppsPosBody.  # noqa: E501
        :rtype: bool
        """
        return self._requires_refund_email

    @requires_refund_email.setter
    def requires_refund_email(self, requires_refund_email):
        """Sets the requires_refund_email of this AppsPosBody.

        Whether to redirect user to redirect URL automatically once invoice is paid. Defaults to what is set in the store settings  # noqa: E501

        :param requires_refund_email: The requires_refund_email of this AppsPosBody.  # noqa: E501
        :type: bool
        """

        self._requires_refund_email = requires_refund_email

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AppsPosBody, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AppsPosBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from pygreenfield.api_client import ApiClient


class InvoicesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def invoices_activate_payment_method(self, store_id, invoice_id, payment_method, **kwargs):  # noqa: E501
        """Activate Payment Method  # noqa: E501

        Activate an invoice payment method (if lazy payments mode is enabled)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.invoices_activate_payment_method(store_id, invoice_id, payment_method, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The store to query (required)
        :param str invoice_id: The invoice to update (required)
        :param str payment_method: The payment method to activate (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.invoices_activate_payment_method_with_http_info(store_id, invoice_id, payment_method, **kwargs)  # noqa: E501
        else:
            (data) = self.invoices_activate_payment_method_with_http_info(store_id, invoice_id, payment_method, **kwargs)  # noqa: E501
            return data

    def invoices_activate_payment_method_with_http_info(self, store_id, invoice_id, payment_method, **kwargs):  # noqa: E501
        """Activate Payment Method  # noqa: E501

        Activate an invoice payment method (if lazy payments mode is enabled)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.invoices_activate_payment_method_with_http_info(store_id, invoice_id, payment_method, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The store to query (required)
        :param str invoice_id: The invoice to update (required)
        :param str payment_method: The payment method to activate (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['store_id', 'invoice_id', 'payment_method']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method invoices_activate_payment_method" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'store_id' is set
        if ('store_id' not in params or
                params['store_id'] is None):
            raise ValueError("Missing the required parameter `store_id` when calling `invoices_activate_payment_method`")  # noqa: E501
        # verify the required parameter 'invoice_id' is set
        if ('invoice_id' not in params or
                params['invoice_id'] is None):
            raise ValueError("Missing the required parameter `invoice_id` when calling `invoices_activate_payment_method`")  # noqa: E501
        # verify the required parameter 'payment_method' is set
        if ('payment_method' not in params or
                params['payment_method'] is None):
            raise ValueError("Missing the required parameter `payment_method` when calling `invoices_activate_payment_method`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'store_id' in params:
            path_params['storeId'] = params['store_id']  # noqa: E501
        if 'invoice_id' in params:
            path_params['invoiceId'] = params['invoice_id']  # noqa: E501
        if 'payment_method' in params:
            path_params['paymentMethod'] = params['payment_method']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_Key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/stores/{storeId}/invoices/{invoiceId}/payment-methods/{paymentMethod}/activate', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def invoices_archive_invoice(self, store_id, invoice_id, **kwargs):  # noqa: E501
        """Archive invoice  # noqa: E501

        Archives the specified invoice.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.invoices_archive_invoice(store_id, invoice_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The store the invoice belongs to (required)
        :param str invoice_id: The invoice to remove (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.invoices_archive_invoice_with_http_info(store_id, invoice_id, **kwargs)  # noqa: E501
        else:
            (data) = self.invoices_archive_invoice_with_http_info(store_id, invoice_id, **kwargs)  # noqa: E501
            return data

    def invoices_archive_invoice_with_http_info(self, store_id, invoice_id, **kwargs):  # noqa: E501
        """Archive invoice  # noqa: E501

        Archives the specified invoice.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.invoices_archive_invoice_with_http_info(store_id, invoice_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The store the invoice belongs to (required)
        :param str invoice_id: The invoice to remove (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['store_id', 'invoice_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method invoices_archive_invoice" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'store_id' is set
        if ('store_id' not in params or
                params['store_id'] is None):
            raise ValueError("Missing the required parameter `store_id` when calling `invoices_archive_invoice`")  # noqa: E501
        # verify the required parameter 'invoice_id' is set
        if ('invoice_id' not in params or
                params['invoice_id'] is None):
            raise ValueError("Missing the required parameter `invoice_id` when calling `invoices_archive_invoice`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'store_id' in params:
            path_params['storeId'] = params['store_id']  # noqa: E501
        if 'invoice_id' in params:
            path_params['invoiceId'] = params['invoice_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_Key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/stores/{storeId}/invoices/{invoiceId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def invoices_create_invoice(self, body, store_id, **kwargs):  # noqa: E501
        """Create a new invoice  # noqa: E501

        Create a new invoice  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.invoices_create_invoice(body, store_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateInvoiceRequest body: (required)
        :param str store_id: The store to query (required)
        :return: InvoiceData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.invoices_create_invoice_with_http_info(body, store_id, **kwargs)  # noqa: E501
        else:
            (data) = self.invoices_create_invoice_with_http_info(body, store_id, **kwargs)  # noqa: E501
            return data

    def invoices_create_invoice_with_http_info(self, body, store_id, **kwargs):  # noqa: E501
        """Create a new invoice  # noqa: E501

        Create a new invoice  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.invoices_create_invoice_with_http_info(body, store_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateInvoiceRequest body: (required)
        :param str store_id: The store to query (required)
        :return: InvoiceData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'store_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method invoices_create_invoice" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `invoices_create_invoice`")  # noqa: E501
        # verify the required parameter 'store_id' is set
        if ('store_id' not in params or
                params['store_id'] is None):
            raise ValueError("Missing the required parameter `store_id` when calling `invoices_create_invoice`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'store_id' in params:
            path_params['storeId'] = params['store_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_Key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/stores/{storeId}/invoices', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InvoiceData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def invoices_get_invoice(self, store_id, invoice_id, **kwargs):  # noqa: E501
        """Get invoice  # noqa: E501

        View information about the specified invoice  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.invoices_get_invoice(store_id, invoice_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The store to fetch (required)
        :param str invoice_id: The invoice to fetch (required)
        :return: InvoiceData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.invoices_get_invoice_with_http_info(store_id, invoice_id, **kwargs)  # noqa: E501
        else:
            (data) = self.invoices_get_invoice_with_http_info(store_id, invoice_id, **kwargs)  # noqa: E501
            return data

    def invoices_get_invoice_with_http_info(self, store_id, invoice_id, **kwargs):  # noqa: E501
        """Get invoice  # noqa: E501

        View information about the specified invoice  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.invoices_get_invoice_with_http_info(store_id, invoice_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The store to fetch (required)
        :param str invoice_id: The invoice to fetch (required)
        :return: InvoiceData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['store_id', 'invoice_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method invoices_get_invoice" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'store_id' is set
        if ('store_id' not in params or
                params['store_id'] is None):
            raise ValueError("Missing the required parameter `store_id` when calling `invoices_get_invoice`")  # noqa: E501
        # verify the required parameter 'invoice_id' is set
        if ('invoice_id' not in params or
                params['invoice_id'] is None):
            raise ValueError("Missing the required parameter `invoice_id` when calling `invoices_get_invoice`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'store_id' in params:
            path_params['storeId'] = params['store_id']  # noqa: E501
        if 'invoice_id' in params:
            path_params['invoiceId'] = params['invoice_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_Key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/stores/{storeId}/invoices/{invoiceId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InvoiceData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def invoices_get_invoice_payment_methods(self, store_id, invoice_id, **kwargs):  # noqa: E501
        """Get invoice payment methods  # noqa: E501

        View information about the specified invoice's payment methods  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.invoices_get_invoice_payment_methods(store_id, invoice_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The store to fetch (required)
        :param str invoice_id: The invoice to fetch (required)
        :param bool only_accounted_payments: If default or true, only returns payments which are accounted (in Bitcoin, this mean not returning RBF'd or double spent payments)
        :return: list[InvoicePaymentMethodDataModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.invoices_get_invoice_payment_methods_with_http_info(store_id, invoice_id, **kwargs)  # noqa: E501
        else:
            (data) = self.invoices_get_invoice_payment_methods_with_http_info(store_id, invoice_id, **kwargs)  # noqa: E501
            return data

    def invoices_get_invoice_payment_methods_with_http_info(self, store_id, invoice_id, **kwargs):  # noqa: E501
        """Get invoice payment methods  # noqa: E501

        View information about the specified invoice's payment methods  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.invoices_get_invoice_payment_methods_with_http_info(store_id, invoice_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The store to fetch (required)
        :param str invoice_id: The invoice to fetch (required)
        :param bool only_accounted_payments: If default or true, only returns payments which are accounted (in Bitcoin, this mean not returning RBF'd or double spent payments)
        :return: list[InvoicePaymentMethodDataModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['store_id', 'invoice_id', 'only_accounted_payments']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method invoices_get_invoice_payment_methods" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'store_id' is set
        if ('store_id' not in params or
                params['store_id'] is None):
            raise ValueError("Missing the required parameter `store_id` when calling `invoices_get_invoice_payment_methods`")  # noqa: E501
        # verify the required parameter 'invoice_id' is set
        if ('invoice_id' not in params or
                params['invoice_id'] is None):
            raise ValueError("Missing the required parameter `invoice_id` when calling `invoices_get_invoice_payment_methods`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'store_id' in params:
            path_params['storeId'] = params['store_id']  # noqa: E501
        if 'invoice_id' in params:
            path_params['invoiceId'] = params['invoice_id']  # noqa: E501

        query_params = []
        if 'only_accounted_payments' in params:
            query_params.append(('onlyAccountedPayments', params['only_accounted_payments']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_Key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/stores/{storeId}/invoices/{invoiceId}/payment-methods', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[InvoicePaymentMethodDataModel]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def invoices_get_invoices(self, store_id, **kwargs):  # noqa: E501
        """Get invoices  # noqa: E501

        View information about the existing invoices  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.invoices_get_invoices(store_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The store to query (required)
        :param list[str] order_id: Array of OrderIds to fetch the invoices for
        :param str text_search: A term that can help locating specific invoices.
        :param float skip: Number of records to skip
        :param float take: Number of records returned in response
        :return: InvoiceDataList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.invoices_get_invoices_with_http_info(store_id, **kwargs)  # noqa: E501
        else:
            (data) = self.invoices_get_invoices_with_http_info(store_id, **kwargs)  # noqa: E501
            return data

    def invoices_get_invoices_with_http_info(self, store_id, **kwargs):  # noqa: E501
        """Get invoices  # noqa: E501

        View information about the existing invoices  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.invoices_get_invoices_with_http_info(store_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The store to query (required)
        :param list[str] order_id: Array of OrderIds to fetch the invoices for
        :param str text_search: A term that can help locating specific invoices.
        :param float skip: Number of records to skip
        :param float take: Number of records returned in response
        :return: InvoiceDataList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['store_id', 'order_id', 'text_search', 'skip', 'take']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method invoices_get_invoices" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'store_id' is set
        if ('store_id' not in params or
                params['store_id'] is None):
            raise ValueError("Missing the required parameter `store_id` when calling `invoices_get_invoices`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'store_id' in params:
            path_params['storeId'] = params['store_id']  # noqa: E501

        query_params = []
        if 'order_id' in params:
            query_params.append(('orderId', params['order_id']))  # noqa: E501
            collection_formats['orderId'] = 'multi'  # noqa: E501
        if 'text_search' in params:
            query_params.append(('textSearch', params['text_search']))  # noqa: E501
        if 'skip' in params:
            query_params.append(('skip', params['skip']))  # noqa: E501
        if 'take' in params:
            query_params.append(('take', params['take']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_Key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/stores/{storeId}/invoices', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InvoiceDataList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def invoices_mark_invoice_status(self, body, store_id, invoice_id, **kwargs):  # noqa: E501
        """Mark invoice status  # noqa: E501

        Mark an invoice as invalid or settled.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.invoices_mark_invoice_status(body, store_id, invoice_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param MarkInvoiceStatusRequest body: (required)
        :param str store_id: The store to query (required)
        :param str invoice_id: The invoice to update (required)
        :return: InvoiceData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.invoices_mark_invoice_status_with_http_info(body, store_id, invoice_id, **kwargs)  # noqa: E501
        else:
            (data) = self.invoices_mark_invoice_status_with_http_info(body, store_id, invoice_id, **kwargs)  # noqa: E501
            return data

    def invoices_mark_invoice_status_with_http_info(self, body, store_id, invoice_id, **kwargs):  # noqa: E501
        """Mark invoice status  # noqa: E501

        Mark an invoice as invalid or settled.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.invoices_mark_invoice_status_with_http_info(body, store_id, invoice_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param MarkInvoiceStatusRequest body: (required)
        :param str store_id: The store to query (required)
        :param str invoice_id: The invoice to update (required)
        :return: InvoiceData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'store_id', 'invoice_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method invoices_mark_invoice_status" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `invoices_mark_invoice_status`")  # noqa: E501
        # verify the required parameter 'store_id' is set
        if ('store_id' not in params or
                params['store_id'] is None):
            raise ValueError("Missing the required parameter `store_id` when calling `invoices_mark_invoice_status`")  # noqa: E501
        # verify the required parameter 'invoice_id' is set
        if ('invoice_id' not in params or
                params['invoice_id'] is None):
            raise ValueError("Missing the required parameter `invoice_id` when calling `invoices_mark_invoice_status`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'store_id' in params:
            path_params['storeId'] = params['store_id']  # noqa: E501
        if 'invoice_id' in params:
            path_params['invoiceId'] = params['invoice_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_Key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/stores/{storeId}/invoices/{invoiceId}/status', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InvoiceData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def invoices_unarchive_invoice(self, store_id, invoice_id, **kwargs):  # noqa: E501
        """Unarchive invoice  # noqa: E501

        Unarchive an invoice  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.invoices_unarchive_invoice(store_id, invoice_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The store to query (required)
        :param str invoice_id: The invoice to update (required)
        :return: InvoiceData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.invoices_unarchive_invoice_with_http_info(store_id, invoice_id, **kwargs)  # noqa: E501
        else:
            (data) = self.invoices_unarchive_invoice_with_http_info(store_id, invoice_id, **kwargs)  # noqa: E501
            return data

    def invoices_unarchive_invoice_with_http_info(self, store_id, invoice_id, **kwargs):  # noqa: E501
        """Unarchive invoice  # noqa: E501

        Unarchive an invoice  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.invoices_unarchive_invoice_with_http_info(store_id, invoice_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The store to query (required)
        :param str invoice_id: The invoice to update (required)
        :return: InvoiceData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['store_id', 'invoice_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method invoices_unarchive_invoice" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'store_id' is set
        if ('store_id' not in params or
                params['store_id'] is None):
            raise ValueError("Missing the required parameter `store_id` when calling `invoices_unarchive_invoice`")  # noqa: E501
        # verify the required parameter 'invoice_id' is set
        if ('invoice_id' not in params or
                params['invoice_id'] is None):
            raise ValueError("Missing the required parameter `invoice_id` when calling `invoices_unarchive_invoice`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'store_id' in params:
            path_params['storeId'] = params['store_id']  # noqa: E501
        if 'invoice_id' in params:
            path_params['invoiceId'] = params['invoice_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_Key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/stores/{storeId}/invoices/{invoiceId}/unarchive', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InvoiceData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def invoices_update_invoice(self, body, store_id, invoice_id, **kwargs):  # noqa: E501
        """Update invoice  # noqa: E501

        Updates the specified invoice.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.invoices_update_invoice(body, store_id, invoice_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateInvoiceRequest body: (required)
        :param str store_id: The store the invoice belongs to (required)
        :param str invoice_id: The invoice to update (required)
        :return: InvoiceData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.invoices_update_invoice_with_http_info(body, store_id, invoice_id, **kwargs)  # noqa: E501
        else:
            (data) = self.invoices_update_invoice_with_http_info(body, store_id, invoice_id, **kwargs)  # noqa: E501
            return data

    def invoices_update_invoice_with_http_info(self, body, store_id, invoice_id, **kwargs):  # noqa: E501
        """Update invoice  # noqa: E501

        Updates the specified invoice.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.invoices_update_invoice_with_http_info(body, store_id, invoice_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateInvoiceRequest body: (required)
        :param str store_id: The store the invoice belongs to (required)
        :param str invoice_id: The invoice to update (required)
        :return: InvoiceData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'store_id', 'invoice_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method invoices_update_invoice" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `invoices_update_invoice`")  # noqa: E501
        # verify the required parameter 'store_id' is set
        if ('store_id' not in params or
                params['store_id'] is None):
            raise ValueError("Missing the required parameter `store_id` when calling `invoices_update_invoice`")  # noqa: E501
        # verify the required parameter 'invoice_id' is set
        if ('invoice_id' not in params or
                params['invoice_id'] is None):
            raise ValueError("Missing the required parameter `invoice_id` when calling `invoices_update_invoice`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'store_id' in params:
            path_params['storeId'] = params['store_id']  # noqa: E501
        if 'invoice_id' in params:
            path_params['invoiceId'] = params['invoice_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_Key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/stores/{storeId}/invoices/{invoiceId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InvoiceData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import pygreenfield
from pygreenfield.api.store_wallet__on_chain_api import StoreWalletOnChainApi  # noqa: E501
from pygreenfield.rest import ApiException


class TestStoreWalletOnChainApi(unittest.TestCase):
    """StoreWalletOnChainApi unit test stubs"""

    def setUp(self):
        self.api = StoreWalletOnChainApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_store_on_chain_wallets_create_on_chain_transaction(self):
        """Test case for store_on_chain_wallets_create_on_chain_transaction

        Create store on-chain wallet transaction  # noqa: E501
        """
        pass

    def test_store_on_chain_wallets_get_on_chain_fee_rate(self):
        """Test case for store_on_chain_wallets_get_on_chain_fee_rate

        Get store on-chain wallet fee rate  # noqa: E501
        """
        pass

    def test_store_on_chain_wallets_get_on_chain_wallet_receive_address(self):
        """Test case for store_on_chain_wallets_get_on_chain_wallet_receive_address

        Get store on-chain wallet address  # noqa: E501
        """
        pass

    def test_store_on_chain_wallets_get_on_chain_wallet_transaction(self):
        """Test case for store_on_chain_wallets_get_on_chain_wallet_transaction

        Get store on-chain wallet transaction  # noqa: E501
        """
        pass

    def test_store_on_chain_wallets_get_on_chain_wallet_utx_os(self):
        """Test case for store_on_chain_wallets_get_on_chain_wallet_utx_os

        Get store on-chain wallet UTXOS  # noqa: E501
        """
        pass

    def test_store_on_chain_wallets_patch_on_chain_wallet_transaction(self):
        """Test case for store_on_chain_wallets_patch_on_chain_wallet_transaction

        Patch store on-chain wallet transaction info  # noqa: E501
        """
        pass

    def test_store_on_chain_wallets_show_on_chain_wallet_overview(self):
        """Test case for store_on_chain_wallets_show_on_chain_wallet_overview

        Get store on-chain wallet overview  # noqa: E501
        """
        pass

    def test_store_on_chain_wallets_show_on_chain_wallet_transactions(self):
        """Test case for store_on_chain_wallets_show_on_chain_wallet_transactions

        Get store on-chain wallet transactions  # noqa: E501
        """
        pass

    def test_store_on_chain_wallets_un_reserve_on_chain_wallet_receive_address(self):
        """Test case for store_on_chain_wallets_un_reserve_on_chain_wallet_receive_address

        UnReserve last store on-chain wallet address  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import pygreenfield
from pygreenfield.api.stores__payouts_api import StoresPayoutsApi  # noqa: E501
from pygreenfield.rest import ApiException


class TestStoresPayoutsApi(unittest.TestCase):
    """StoresPayoutsApi unit test stubs"""

    def setUp(self):
        self.api = StoresPayoutsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_payouts_create_payout_through_store(self):
        """Test case for payouts_create_payout_through_store

        Create Payout   # noqa: E501
        """
        pass

    def test_pull_payments_approve_payout(self):
        """Test case for pull_payments_approve_payout

        Approve Payout  # noqa: E501
        """
        pass

    def test_pull_payments_cancel_payout(self):
        """Test case for pull_payments_cancel_payout

        Cancel Payout  # noqa: E501
        """
        pass

    def test_pull_payments_get_store_payouts(self):
        """Test case for pull_payments_get_store_payouts

        Get Store Payouts  # noqa: E501
        """
        pass

    def test_pull_payments_mark_payout_paid(self):
        """Test case for pull_payments_mark_payout_paid

        Mark Payout as Paid  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class LightningNodeInformationData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'node_ur_is': 'list[str]',
        'block_height': 'int'
    }

    attribute_map = {
        'node_ur_is': 'nodeURIs',
        'block_height': 'blockHeight'
    }

    def __init__(self, node_ur_is=None, block_height=None):  # noqa: E501
        """LightningNodeInformationData - a model defined in Swagger"""  # noqa: E501
        self._node_ur_is = None
        self._block_height = None
        self.discriminator = None
        if node_ur_is is not None:
            self.node_ur_is = node_ur_is
        if block_height is not None:
            self.block_height = block_height

    @property
    def node_ur_is(self):
        """Gets the node_ur_is of this LightningNodeInformationData.  # noqa: E501

        Node URIs to connect to this node in the form `pubkey@endpoint[:port]`  # noqa: E501

        :return: The node_ur_is of this LightningNodeInformationData.  # noqa: E501
        :rtype: list[str]
        """
        return self._node_ur_is

    @node_ur_is.setter
    def node_ur_is(self, node_ur_is):
        """Sets the node_ur_is of this LightningNodeInformationData.

        Node URIs to connect to this node in the form `pubkey@endpoint[:port]`  # noqa: E501

        :param node_ur_is: The node_ur_is of this LightningNodeInformationData.  # noqa: E501
        :type: list[str]
        """

        self._node_ur_is = node_ur_is

    @property
    def block_height(self):
        """Gets the block_height of this LightningNodeInformationData.  # noqa: E501

        The block height of the lightning node  # noqa: E501

        :return: The block_height of this LightningNodeInformationData.  # noqa: E501
        :rtype: int
        """
        return self._block_height

    @block_height.setter
    def block_height(self, block_height):
        """Sets the block_height of this LightningNodeInformationData.

        The block height of the lightning node  # noqa: E501

        :param block_height: The block_height of this LightningNodeInformationData.  # noqa: E501
        :type: int
        """

        self._block_height = block_height

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LightningNodeInformationData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LightningNodeInformationData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ApplicationServerInfoData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'version': 'str',
        'onion': 'str',
        'supported_payment_methods': 'list[str]',
        'fully_synched': 'bool',
        'sync_status': 'list[ApplicationServerInfoSyncStatusData]'
    }

    attribute_map = {
        'version': 'version',
        'onion': 'onion',
        'supported_payment_methods': 'supportedPaymentMethods',
        'fully_synched': 'fullySynched',
        'sync_status': 'syncStatus'
    }

    def __init__(self, version=None, onion=None, supported_payment_methods=None, fully_synched=None, sync_status=None):  # noqa: E501
        """ApplicationServerInfoData - a model defined in Swagger"""  # noqa: E501
        self._version = None
        self._onion = None
        self._supported_payment_methods = None
        self._fully_synched = None
        self._sync_status = None
        self.discriminator = None
        if version is not None:
            self.version = version
        if onion is not None:
            self.onion = onion
        if supported_payment_methods is not None:
            self.supported_payment_methods = supported_payment_methods
        if fully_synched is not None:
            self.fully_synched = fully_synched
        if sync_status is not None:
            self.sync_status = sync_status

    @property
    def version(self):
        """Gets the version of this ApplicationServerInfoData.  # noqa: E501

        BTCPay Server version  # noqa: E501

        :return: The version of this ApplicationServerInfoData.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this ApplicationServerInfoData.

        BTCPay Server version  # noqa: E501

        :param version: The version of this ApplicationServerInfoData.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def onion(self):
        """Gets the onion of this ApplicationServerInfoData.  # noqa: E501

        The Tor hostname  # noqa: E501

        :return: The onion of this ApplicationServerInfoData.  # noqa: E501
        :rtype: str
        """
        return self._onion

    @onion.setter
    def onion(self, onion):
        """Sets the onion of this ApplicationServerInfoData.

        The Tor hostname  # noqa: E501

        :param onion: The onion of this ApplicationServerInfoData.  # noqa: E501
        :type: str
        """

        self._onion = onion

    @property
    def supported_payment_methods(self):
        """Gets the supported_payment_methods of this ApplicationServerInfoData.  # noqa: E501

        The payment methods this server supports  # noqa: E501

        :return: The supported_payment_methods of this ApplicationServerInfoData.  # noqa: E501
        :rtype: list[str]
        """
        return self._supported_payment_methods

    @supported_payment_methods.setter
    def supported_payment_methods(self, supported_payment_methods):
        """Sets the supported_payment_methods of this ApplicationServerInfoData.

        The payment methods this server supports  # noqa: E501

        :param supported_payment_methods: The supported_payment_methods of this ApplicationServerInfoData.  # noqa: E501
        :type: list[str]
        """

        self._supported_payment_methods = supported_payment_methods

    @property
    def fully_synched(self):
        """Gets the fully_synched of this ApplicationServerInfoData.  # noqa: E501

        True if the instance is fully synchronized, according to NBXplorer  # noqa: E501

        :return: The fully_synched of this ApplicationServerInfoData.  # noqa: E501
        :rtype: bool
        """
        return self._fully_synched

    @fully_synched.setter
    def fully_synched(self, fully_synched):
        """Sets the fully_synched of this ApplicationServerInfoData.

        True if the instance is fully synchronized, according to NBXplorer  # noqa: E501

        :param fully_synched: The fully_synched of this ApplicationServerInfoData.  # noqa: E501
        :type: bool
        """

        self._fully_synched = fully_synched

    @property
    def sync_status(self):
        """Gets the sync_status of this ApplicationServerInfoData.  # noqa: E501


        :return: The sync_status of this ApplicationServerInfoData.  # noqa: E501
        :rtype: list[ApplicationServerInfoSyncStatusData]
        """
        return self._sync_status

    @sync_status.setter
    def sync_status(self, sync_status):
        """Sets the sync_status of this ApplicationServerInfoData.


        :param sync_status: The sync_status of this ApplicationServerInfoData.  # noqa: E501
        :type: list[ApplicationServerInfoSyncStatusData]
        """

        self._sync_status = sync_status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ApplicationServerInfoData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApplicationServerInfoData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PayoutData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'revision': 'int',
        'pull_payment_id': 'str',
        '_date': 'str',
        'destination': 'str',
        'amount': 'str',
        'payment_method': 'str',
        'crypto_code': 'str',
        'payment_method_amount': 'str',
        'state': 'str'
    }

    attribute_map = {
        'id': 'id',
        'revision': 'revision',
        'pull_payment_id': 'pullPaymentId',
        '_date': 'date',
        'destination': 'destination',
        'amount': 'amount',
        'payment_method': 'paymentMethod',
        'crypto_code': 'cryptoCode',
        'payment_method_amount': 'paymentMethodAmount',
        'state': 'state'
    }

    def __init__(self, id=None, revision=None, pull_payment_id=None, _date=None, destination=None, amount=None, payment_method=None, crypto_code=None, payment_method_amount=None, state=None):  # noqa: E501
        """PayoutData - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._revision = None
        self._pull_payment_id = None
        self.__date = None
        self._destination = None
        self._amount = None
        self._payment_method = None
        self._crypto_code = None
        self._payment_method_amount = None
        self._state = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if revision is not None:
            self.revision = revision
        if pull_payment_id is not None:
            self.pull_payment_id = pull_payment_id
        if _date is not None:
            self._date = _date
        if destination is not None:
            self.destination = destination
        if amount is not None:
            self.amount = amount
        if payment_method is not None:
            self.payment_method = payment_method
        if crypto_code is not None:
            self.crypto_code = crypto_code
        if payment_method_amount is not None:
            self.payment_method_amount = payment_method_amount
        if state is not None:
            self.state = state

    @property
    def id(self):
        """Gets the id of this PayoutData.  # noqa: E501

        The id of the payout  # noqa: E501

        :return: The id of this PayoutData.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PayoutData.

        The id of the payout  # noqa: E501

        :param id: The id of this PayoutData.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def revision(self):
        """Gets the revision of this PayoutData.  # noqa: E501

        The revision number of the payout. This revision number is incremented when the payout amount or destination is modified before the approval.  # noqa: E501

        :return: The revision of this PayoutData.  # noqa: E501
        :rtype: int
        """
        return self._revision

    @revision.setter
    def revision(self, revision):
        """Sets the revision of this PayoutData.

        The revision number of the payout. This revision number is incremented when the payout amount or destination is modified before the approval.  # noqa: E501

        :param revision: The revision of this PayoutData.  # noqa: E501
        :type: int
        """

        self._revision = revision

    @property
    def pull_payment_id(self):
        """Gets the pull_payment_id of this PayoutData.  # noqa: E501

        The id of the pull payment this payout belongs to  # noqa: E501

        :return: The pull_payment_id of this PayoutData.  # noqa: E501
        :rtype: str
        """
        return self._pull_payment_id

    @pull_payment_id.setter
    def pull_payment_id(self, pull_payment_id):
        """Sets the pull_payment_id of this PayoutData.

        The id of the pull payment this payout belongs to  # noqa: E501

        :param pull_payment_id: The pull_payment_id of this PayoutData.  # noqa: E501
        :type: str
        """

        self._pull_payment_id = pull_payment_id

    @property
    def _date(self):
        """Gets the _date of this PayoutData.  # noqa: E501

        The creation date of the payout as a unix timestamp  # noqa: E501

        :return: The _date of this PayoutData.  # noqa: E501
        :rtype: str
        """
        return self.__date

    @_date.setter
    def _date(self, _date):
        """Sets the _date of this PayoutData.

        The creation date of the payout as a unix timestamp  # noqa: E501

        :param _date: The _date of this PayoutData.  # noqa: E501
        :type: str
        """

        self.__date = _date

    @property
    def destination(self):
        """Gets the destination of this PayoutData.  # noqa: E501

        The destination of the payout (can be an address or a BIP21 url)  # noqa: E501

        :return: The destination of this PayoutData.  # noqa: E501
        :rtype: str
        """
        return self._destination

    @destination.setter
    def destination(self, destination):
        """Sets the destination of this PayoutData.

        The destination of the payout (can be an address or a BIP21 url)  # noqa: E501

        :param destination: The destination of this PayoutData.  # noqa: E501
        :type: str
        """

        self._destination = destination

    @property
    def amount(self):
        """Gets the amount of this PayoutData.  # noqa: E501

        The amount of the payout in the currency of the pull payment (eg. USD).  # noqa: E501

        :return: The amount of this PayoutData.  # noqa: E501
        :rtype: str
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this PayoutData.

        The amount of the payout in the currency of the pull payment (eg. USD).  # noqa: E501

        :param amount: The amount of this PayoutData.  # noqa: E501
        :type: str
        """

        self._amount = amount

    @property
    def payment_method(self):
        """Gets the payment_method of this PayoutData.  # noqa: E501

        The payment method of the payout (e.g., \"BTC\" or \"BTC_LightningLike\"  # noqa: E501

        :return: The payment_method of this PayoutData.  # noqa: E501
        :rtype: str
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """Sets the payment_method of this PayoutData.

        The payment method of the payout (e.g., \"BTC\" or \"BTC_LightningLike\"  # noqa: E501

        :param payment_method: The payment_method of this PayoutData.  # noqa: E501
        :type: str
        """

        self._payment_method = payment_method

    @property
    def crypto_code(self):
        """Gets the crypto_code of this PayoutData.  # noqa: E501

        Crypto code of the payment method of the payout (e.g., \"BTC\" or \"LTC\")  # noqa: E501

        :return: The crypto_code of this PayoutData.  # noqa: E501
        :rtype: str
        """
        return self._crypto_code

    @crypto_code.setter
    def crypto_code(self, crypto_code):
        """Sets the crypto_code of this PayoutData.

        Crypto code of the payment method of the payout (e.g., \"BTC\" or \"LTC\")  # noqa: E501

        :param crypto_code: The crypto_code of this PayoutData.  # noqa: E501
        :type: str
        """

        self._crypto_code = crypto_code

    @property
    def payment_method_amount(self):
        """Gets the payment_method_amount of this PayoutData.  # noqa: E501

        The amount of the payout in the currency of the payment method (eg. BTC). This is only available from the `AwaitingPayment` state.  # noqa: E501

        :return: The payment_method_amount of this PayoutData.  # noqa: E501
        :rtype: str
        """
        return self._payment_method_amount

    @payment_method_amount.setter
    def payment_method_amount(self, payment_method_amount):
        """Sets the payment_method_amount of this PayoutData.

        The amount of the payout in the currency of the payment method (eg. BTC). This is only available from the `AwaitingPayment` state.  # noqa: E501

        :param payment_method_amount: The payment_method_amount of this PayoutData.  # noqa: E501
        :type: str
        """

        self._payment_method_amount = payment_method_amount

    @property
    def state(self):
        """Gets the state of this PayoutData.  # noqa: E501

        The state of the payout (`AwaitingApproval`, `AwaitingPayment`, `InProgress`, `Completed`, `Cancelled`)  # noqa: E501

        :return: The state of this PayoutData.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this PayoutData.

        The state of the payout (`AwaitingApproval`, `AwaitingPayment`, `InProgress`, `Completed`, `Cancelled`)  # noqa: E501

        :param state: The state of this PayoutData.  # noqa: E501
        :type: str
        """
        allowed_values = ["AwaitingApproval", "AwaitingPayment", "InProgress", "Completed", "Cancelled"]  # noqa: E501
        if state not in allowed_values:
            raise ValueError(
                "Invalid value for `state` ({0}), must be one of {1}"  # noqa: E501
                .format(state, allowed_values)
            )

        self._state = state

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PayoutData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PayoutData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class StoreIdPullpaymentsBody(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'description': 'str',
        'amount': 'str',
        'currency': 'str',
        'period': 'int',
        'bolt11_expiration': 'str',
        'auto_approve_claims': 'bool',
        'starts_at': 'int',
        'expires_at': 'int',
        'payment_methods': 'list[str]'
    }

    attribute_map = {
        'name': 'name',
        'description': 'description',
        'amount': 'amount',
        'currency': 'currency',
        'period': 'period',
        'bolt11_expiration': 'BOLT11Expiration',
        'auto_approve_claims': 'autoApproveClaims',
        'starts_at': 'startsAt',
        'expires_at': 'expiresAt',
        'payment_methods': 'paymentMethods'
    }

    def __init__(self, name=None, description=None, amount=None, currency=None, period=None, bolt11_expiration='30', auto_approve_claims=False, starts_at=None, expires_at=None, payment_methods=None):  # noqa: E501
        """StoreIdPullpaymentsBody - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._description = None
        self._amount = None
        self._currency = None
        self._period = None
        self._bolt11_expiration = None
        self._auto_approve_claims = None
        self._starts_at = None
        self._expires_at = None
        self._payment_methods = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if amount is not None:
            self.amount = amount
        if currency is not None:
            self.currency = currency
        if period is not None:
            self.period = period
        if bolt11_expiration is not None:
            self.bolt11_expiration = bolt11_expiration
        if auto_approve_claims is not None:
            self.auto_approve_claims = auto_approve_claims
        if starts_at is not None:
            self.starts_at = starts_at
        if expires_at is not None:
            self.expires_at = expires_at
        if payment_methods is not None:
            self.payment_methods = payment_methods

    @property
    def name(self):
        """Gets the name of this StoreIdPullpaymentsBody.  # noqa: E501

        The name of the pull payment  # noqa: E501

        :return: The name of this StoreIdPullpaymentsBody.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this StoreIdPullpaymentsBody.

        The name of the pull payment  # noqa: E501

        :param name: The name of this StoreIdPullpaymentsBody.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """Gets the description of this StoreIdPullpaymentsBody.  # noqa: E501

        The description of the pull payment  # noqa: E501

        :return: The description of this StoreIdPullpaymentsBody.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this StoreIdPullpaymentsBody.

        The description of the pull payment  # noqa: E501

        :param description: The description of this StoreIdPullpaymentsBody.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def amount(self):
        """Gets the amount of this StoreIdPullpaymentsBody.  # noqa: E501

        The amount in `currency` of this pull payment as a decimal string  # noqa: E501

        :return: The amount of this StoreIdPullpaymentsBody.  # noqa: E501
        :rtype: str
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this StoreIdPullpaymentsBody.

        The amount in `currency` of this pull payment as a decimal string  # noqa: E501

        :param amount: The amount of this StoreIdPullpaymentsBody.  # noqa: E501
        :type: str
        """

        self._amount = amount

    @property
    def currency(self):
        """Gets the currency of this StoreIdPullpaymentsBody.  # noqa: E501

        The currency of the amount.  # noqa: E501

        :return: The currency of this StoreIdPullpaymentsBody.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this StoreIdPullpaymentsBody.

        The currency of the amount.  # noqa: E501

        :param currency: The currency of this StoreIdPullpaymentsBody.  # noqa: E501
        :type: str
        """

        self._currency = currency

    @property
    def period(self):
        """Gets the period of this StoreIdPullpaymentsBody.  # noqa: E501

        The length of each period in seconds.  # noqa: E501

        :return: The period of this StoreIdPullpaymentsBody.  # noqa: E501
        :rtype: int
        """
        return self._period

    @period.setter
    def period(self, period):
        """Sets the period of this StoreIdPullpaymentsBody.

        The length of each period in seconds.  # noqa: E501

        :param period: The period of this StoreIdPullpaymentsBody.  # noqa: E501
        :type: int
        """

        self._period = period

    @property
    def bolt11_expiration(self):
        """Gets the bolt11_expiration of this StoreIdPullpaymentsBody.  # noqa: E501

        If lightning is activated, do not accept BOLT11 invoices with expiration less than … days  # noqa: E501

        :return: The bolt11_expiration of this StoreIdPullpaymentsBody.  # noqa: E501
        :rtype: str
        """
        return self._bolt11_expiration

    @bolt11_expiration.setter
    def bolt11_expiration(self, bolt11_expiration):
        """Sets the bolt11_expiration of this StoreIdPullpaymentsBody.

        If lightning is activated, do not accept BOLT11 invoices with expiration less than … days  # noqa: E501

        :param bolt11_expiration: The bolt11_expiration of this StoreIdPullpaymentsBody.  # noqa: E501
        :type: str
        """

        self._bolt11_expiration = bolt11_expiration

    @property
    def auto_approve_claims(self):
        """Gets the auto_approve_claims of this StoreIdPullpaymentsBody.  # noqa: E501

        Any payouts created for this pull payment will skip the approval phase upon creation  # noqa: E501

        :return: The auto_approve_claims of this StoreIdPullpaymentsBody.  # noqa: E501
        :rtype: bool
        """
        return self._auto_approve_claims

    @auto_approve_claims.setter
    def auto_approve_claims(self, auto_approve_claims):
        """Sets the auto_approve_claims of this StoreIdPullpaymentsBody.

        Any payouts created for this pull payment will skip the approval phase upon creation  # noqa: E501

        :param auto_approve_claims: The auto_approve_claims of this StoreIdPullpaymentsBody.  # noqa: E501
        :type: bool
        """

        self._auto_approve_claims = auto_approve_claims

    @property
    def starts_at(self):
        """Gets the starts_at of this StoreIdPullpaymentsBody.  # noqa: E501

        When this pull payment is effective. Already started if null or unspecified.  # noqa: E501

        :return: The starts_at of this StoreIdPullpaymentsBody.  # noqa: E501
        :rtype: int
        """
        return self._starts_at

    @starts_at.setter
    def starts_at(self, starts_at):
        """Sets the starts_at of this StoreIdPullpaymentsBody.

        When this pull payment is effective. Already started if null or unspecified.  # noqa: E501

        :param starts_at: The starts_at of this StoreIdPullpaymentsBody.  # noqa: E501
        :type: int
        """

        self._starts_at = starts_at

    @property
    def expires_at(self):
        """Gets the expires_at of this StoreIdPullpaymentsBody.  # noqa: E501

        When this pull payment expires. Never expires if null or unspecified.  # noqa: E501

        :return: The expires_at of this StoreIdPullpaymentsBody.  # noqa: E501
        :rtype: int
        """
        return self._expires_at

    @expires_at.setter
    def expires_at(self, expires_at):
        """Sets the expires_at of this StoreIdPullpaymentsBody.

        When this pull payment expires. Never expires if null or unspecified.  # noqa: E501

        :param expires_at: The expires_at of this StoreIdPullpaymentsBody.  # noqa: E501
        :type: int
        """

        self._expires_at = expires_at

    @property
    def payment_methods(self):
        """Gets the payment_methods of this StoreIdPullpaymentsBody.  # noqa: E501

        The list of supported payment methods supported by this pull payment. Available options can be queried from the `StorePaymentMethods_GetStorePaymentMethods` endpoint  # noqa: E501

        :return: The payment_methods of this StoreIdPullpaymentsBody.  # noqa: E501
        :rtype: list[str]
        """
        return self._payment_methods

    @payment_methods.setter
    def payment_methods(self, payment_methods):
        """Sets the payment_methods of this StoreIdPullpaymentsBody.

        The list of supported payment methods supported by this pull payment. Available options can be queried from the `StorePaymentMethods_GetStorePaymentMethods` endpoint  # noqa: E501

        :param payment_methods: The payment_methods of this StoreIdPullpaymentsBody.  # noqa: E501
        :type: list[str]
        """

        self._payment_methods = payment_methods

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StoreIdPullpaymentsBody, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StoreIdPullpaymentsBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import pygreenfield
from pygreenfield.api.store_payment_methods__on_chain_api import StorePaymentMethodsOnChainApi  # noqa: E501
from pygreenfield.rest import ApiException


class TestStorePaymentMethodsOnChainApi(unittest.TestCase):
    """StorePaymentMethodsOnChainApi unit test stubs"""

    def setUp(self):
        self.api = StorePaymentMethodsOnChainApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_api_v1_stores_store_id_payment_methods_onchain_crypto_code_delete(self):
        """Test case for api_v1_stores_store_id_payment_methods_onchain_crypto_code_delete

        Remove store on-chain payment method  # noqa: E501
        """
        pass

    def test_store_on_chain_payment_methods_generate_on_chain_wallet(self):
        """Test case for store_on_chain_payment_methods_generate_on_chain_wallet

        Generate store on-chain wallet  # noqa: E501
        """
        pass

    def test_store_on_chain_payment_methods_get_on_chain_payment_method(self):
        """Test case for store_on_chain_payment_methods_get_on_chain_payment_method

        Get store on-chain payment method  # noqa: E501
        """
        pass

    def test_store_on_chain_payment_methods_get_on_chain_payment_method_preview(self):
        """Test case for store_on_chain_payment_methods_get_on_chain_payment_method_preview

        Preview store on-chain payment method addresses  # noqa: E501
        """
        pass

    def test_store_on_chain_payment_methods_get_on_chain_payment_methods(self):
        """Test case for store_on_chain_payment_methods_get_on_chain_payment_methods

        Get store on-chain payment methods  # noqa: E501
        """
        pass

    def test_store_on_chain_payment_methods_post_on_chain_payment_method_preview(self):
        """Test case for store_on_chain_payment_methods_post_on_chain_payment_method_preview

        Preview proposed store on-chain payment method addresses  # noqa: E501
        """
        pass

    def test_store_on_chain_payment_methods_update_on_chain_payment_method(self):
        """Test case for store_on_chain_payment_methods_update_on_chain_payment_method

        Update store on-chain payment method  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class WebhookDataBaseAuthorizedEvents(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'everything': 'bool',
        'specific_events': 'list[str]'
    }

    attribute_map = {
        'everything': 'everything',
        'specific_events': 'specificEvents'
    }

    def __init__(self, everything=True, specific_events=None):  # noqa: E501
        """WebhookDataBaseAuthorizedEvents - a model defined in Swagger"""  # noqa: E501
        self._everything = None
        self._specific_events = None
        self.discriminator = None
        if everything is not None:
            self.everything = everything
        if specific_events is not None:
            self.specific_events = specific_events

    @property
    def everything(self):
        """Gets the everything of this WebhookDataBaseAuthorizedEvents.  # noqa: E501

        If true, the endpoint will receive all events related to the store.  # noqa: E501

        :return: The everything of this WebhookDataBaseAuthorizedEvents.  # noqa: E501
        :rtype: bool
        """
        return self._everything

    @everything.setter
    def everything(self, everything):
        """Sets the everything of this WebhookDataBaseAuthorizedEvents.

        If true, the endpoint will receive all events related to the store.  # noqa: E501

        :param everything: The everything of this WebhookDataBaseAuthorizedEvents.  # noqa: E501
        :type: bool
        """

        self._everything = everything

    @property
    def specific_events(self):
        """Gets the specific_events of this WebhookDataBaseAuthorizedEvents.  # noqa: E501

        If `everything` is false, the specific events that the endpoint is interested in. Current events are: `InvoiceCreated`, `InvoiceReceivedPayment`, `InvoiceProcessing`, `InvoiceExpired`, `InvoiceSettled`, `InvoiceInvalid`.  # noqa: E501

        :return: The specific_events of this WebhookDataBaseAuthorizedEvents.  # noqa: E501
        :rtype: list[str]
        """
        return self._specific_events

    @specific_events.setter
    def specific_events(self, specific_events):
        """Sets the specific_events of this WebhookDataBaseAuthorizedEvents.

        If `everything` is false, the specific events that the endpoint is interested in. Current events are: `InvoiceCreated`, `InvoiceReceivedPayment`, `InvoiceProcessing`, `InvoiceExpired`, `InvoiceSettled`, `InvoiceInvalid`.  # noqa: E501

        :param specific_events: The specific_events of this WebhookDataBaseAuthorizedEvents.  # noqa: E501
        :type: list[str]
        """

        self._specific_events = specific_events

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WebhookDataBaseAuthorizedEvents, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WebhookDataBaseAuthorizedEvents):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import pygreenfield
from pygreenfield.api.lightning__store_api import LightningStoreApi  # noqa: E501
from pygreenfield.rest import ApiException


class TestLightningStoreApi(unittest.TestCase):
    """LightningStoreApi unit test stubs"""

    def setUp(self):
        self.api = LightningStoreApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_store_lightning_node_api_connect_to_node(self):
        """Test case for store_lightning_node_api_connect_to_node

        Connect to lightning node  # noqa: E501
        """
        pass

    def test_store_lightning_node_api_create_invoice(self):
        """Test case for store_lightning_node_api_create_invoice

        Create lightning invoice  # noqa: E501
        """
        pass

    def test_store_lightning_node_api_get_balance(self):
        """Test case for store_lightning_node_api_get_balance

        Get node balance  # noqa: E501
        """
        pass

    def test_store_lightning_node_api_get_channels(self):
        """Test case for store_lightning_node_api_get_channels

        Get channels  # noqa: E501
        """
        pass

    def test_store_lightning_node_api_get_deposit_address(self):
        """Test case for store_lightning_node_api_get_deposit_address

        Get deposit address  # noqa: E501
        """
        pass

    def test_store_lightning_node_api_get_info(self):
        """Test case for store_lightning_node_api_get_info

        Get node information  # noqa: E501
        """
        pass

    def test_store_lightning_node_api_get_invoice(self):
        """Test case for store_lightning_node_api_get_invoice

        Get invoice  # noqa: E501
        """
        pass

    def test_store_lightning_node_api_get_payment(self):
        """Test case for store_lightning_node_api_get_payment

        Get payment  # noqa: E501
        """
        pass

    def test_store_lightning_node_api_open_channel(self):
        """Test case for store_lightning_node_api_open_channel

        Open channel  # noqa: E501
        """
        pass

    def test_store_lightning_node_api_pay_invoice(self):
        """Test case for store_lightning_node_api_pay_invoice

        Pay Lightning Invoice  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class LNURLPayPaymentMethodData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'use_bech32_scheme': 'bool',
        'enable_for_standard_invoices': 'bool',
        'lud12_enabled': 'bool'
    }

    attribute_map = {
        'use_bech32_scheme': 'useBech32Scheme',
        'enable_for_standard_invoices': 'enableForStandardInvoices',
        'lud12_enabled': 'lud12Enabled'
    }

    def __init__(self, use_bech32_scheme=None, enable_for_standard_invoices=None, lud12_enabled=None):  # noqa: E501
        """LNURLPayPaymentMethodData - a model defined in Swagger"""  # noqa: E501
        self._use_bech32_scheme = None
        self._enable_for_standard_invoices = None
        self._lud12_enabled = None
        self.discriminator = None
        if use_bech32_scheme is not None:
            self.use_bech32_scheme = use_bech32_scheme
        if enable_for_standard_invoices is not None:
            self.enable_for_standard_invoices = enable_for_standard_invoices
        if lud12_enabled is not None:
            self.lud12_enabled = lud12_enabled

    @property
    def use_bech32_scheme(self):
        """Gets the use_bech32_scheme of this LNURLPayPaymentMethodData.  # noqa: E501

        Whether to use [LUD-01](https://github.com/fiatjaf/lnurl-rfc/blob/luds/01.md)'s bech32 format or to use [LUD-17](https://github.com/fiatjaf/lnurl-rfc/blob/luds/17.md) url formatting.   # noqa: E501

        :return: The use_bech32_scheme of this LNURLPayPaymentMethodData.  # noqa: E501
        :rtype: bool
        """
        return self._use_bech32_scheme

    @use_bech32_scheme.setter
    def use_bech32_scheme(self, use_bech32_scheme):
        """Sets the use_bech32_scheme of this LNURLPayPaymentMethodData.

        Whether to use [LUD-01](https://github.com/fiatjaf/lnurl-rfc/blob/luds/01.md)'s bech32 format or to use [LUD-17](https://github.com/fiatjaf/lnurl-rfc/blob/luds/17.md) url formatting.   # noqa: E501

        :param use_bech32_scheme: The use_bech32_scheme of this LNURLPayPaymentMethodData.  # noqa: E501
        :type: bool
        """

        self._use_bech32_scheme = use_bech32_scheme

    @property
    def enable_for_standard_invoices(self):
        """Gets the enable_for_standard_invoices of this LNURLPayPaymentMethodData.  # noqa: E501

        Whether to allow this payment method to also be used for standard invoices and not just topup invoices.  # noqa: E501

        :return: The enable_for_standard_invoices of this LNURLPayPaymentMethodData.  # noqa: E501
        :rtype: bool
        """
        return self._enable_for_standard_invoices

    @enable_for_standard_invoices.setter
    def enable_for_standard_invoices(self, enable_for_standard_invoices):
        """Sets the enable_for_standard_invoices of this LNURLPayPaymentMethodData.

        Whether to allow this payment method to also be used for standard invoices and not just topup invoices.  # noqa: E501

        :param enable_for_standard_invoices: The enable_for_standard_invoices of this LNURLPayPaymentMethodData.  # noqa: E501
        :type: bool
        """

        self._enable_for_standard_invoices = enable_for_standard_invoices

    @property
    def lud12_enabled(self):
        """Gets the lud12_enabled of this LNURLPayPaymentMethodData.  # noqa: E501

        Allow comments to be passed on via lnurl.  # noqa: E501

        :return: The lud12_enabled of this LNURLPayPaymentMethodData.  # noqa: E501
        :rtype: bool
        """
        return self._lud12_enabled

    @lud12_enabled.setter
    def lud12_enabled(self, lud12_enabled):
        """Sets the lud12_enabled of this LNURLPayPaymentMethodData.

        Allow comments to be passed on via lnurl.  # noqa: E501

        :param lud12_enabled: The lud12_enabled of this LNURLPayPaymentMethodData.  # noqa: E501
        :type: bool
        """

        self._lud12_enabled = lud12_enabled

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LNURLPayPaymentMethodData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LNURLPayPaymentMethodData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import pygreenfield
from pygreenfield.api.custodians_api import CustodiansApi  # noqa: E501
from pygreenfield.rest import ApiException


class TestCustodiansApi(unittest.TestCase):
    """CustodiansApi unit test stubs"""

    def setUp(self):
        self.api = CustodiansApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_api_v1_stores_store_id_custodian_accounts_account_id_addresses_payment_method_get(self):
        """Test case for api_v1_stores_store_id_custodian_accounts_account_id_addresses_payment_method_get

        Get a deposit address for custodian  # noqa: E501
        """
        pass

    def test_api_v1_stores_store_id_custodian_accounts_account_id_delete(self):
        """Test case for api_v1_stores_store_id_custodian_accounts_account_id_delete

        Delete store custodian account  # noqa: E501
        """
        pass

    def test_api_v1_stores_store_id_custodian_accounts_account_id_get(self):
        """Test case for api_v1_stores_store_id_custodian_accounts_account_id_get

        Get store custodian account  # noqa: E501
        """
        pass

    def test_api_v1_stores_store_id_custodian_accounts_account_id_put(self):
        """Test case for api_v1_stores_store_id_custodian_accounts_account_id_put

        Update custodial account  # noqa: E501
        """
        pass

    def test_api_v1_stores_store_id_custodian_accounts_account_id_trades_market_post(self):
        """Test case for api_v1_stores_store_id_custodian_accounts_account_id_trades_market_post

        Trade one asset for another  # noqa: E501
        """
        pass

    def test_api_v1_stores_store_id_custodian_accounts_account_id_trades_quote_get(self):
        """Test case for api_v1_stores_store_id_custodian_accounts_account_id_trades_quote_get

        Get quote for trading one asset for another  # noqa: E501
        """
        pass

    def test_api_v1_stores_store_id_custodian_accounts_account_id_withdrawals_post(self):
        """Test case for api_v1_stores_store_id_custodian_accounts_account_id_withdrawals_post

        Withdraw to store wallet  # noqa: E501
        """
        pass

    def test_api_v1_stores_store_id_custodian_accounts_account_id_withdrawals_withdrawal_id_post(self):
        """Test case for api_v1_stores_store_id_custodian_accounts_account_id_withdrawals_withdrawal_id_post

        Get withdrawal info  # noqa: E501
        """
        pass

    def test_api_v1_stores_store_id_custodian_accounts_get(self):
        """Test case for api_v1_stores_store_id_custodian_accounts_get

        List store custodian accounts  # noqa: E501
        """
        pass

    def test_api_v1_stores_store_id_custodian_accounts_post(self):
        """Test case for api_v1_stores_store_id_custodian_accounts_post

        Add a custodial account to a store.  # noqa: E501
        """
        pass

    def test_custodians_get_supported_custodians(self):
        """Test case for custodians_get_supported_custodians

        List supported custodians  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from pygreenfield.api_client import ApiClient


class AuthorizationApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def api_keys_authorize_get(self, **kwargs):  # noqa: E501
        """Authorize User  # noqa: E501

        Redirect the browser to this endpoint to request the user to generate an api-key with specific permissions  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_keys_authorize_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] permissions: The permissions to request. (See API Key authentication)
        :param str application_name: The name of your application
        :param bool strict: If permissions are specified, and strict is set to false, it will allow the user to reject some of permissions the application is requesting.
        :param bool selective_stores: If the application is requesting the CanModifyStoreSettings permission and selectiveStores is set to true, this allows the user to only grant permissions to selected stores under the user's control.
        :param str redirect: The url to redirect to after the user consents, with the query parameters appended to it: permissions, user-id, api-key. If not specified, user is redirected to their API Key list.
        :param str application_identifier: If specified, BTCPay Server will check if there is an existing API key associated with the user that also has this application identifier, redirect host AND the permissions required match(takes selectiveStores and strict into account). `applicationIdentifier` is ignored if redirect is not specified.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.api_keys_authorize_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.api_keys_authorize_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def api_keys_authorize_get_with_http_info(self, **kwargs):  # noqa: E501
        """Authorize User  # noqa: E501

        Redirect the browser to this endpoint to request the user to generate an api-key with specific permissions  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_keys_authorize_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] permissions: The permissions to request. (See API Key authentication)
        :param str application_name: The name of your application
        :param bool strict: If permissions are specified, and strict is set to false, it will allow the user to reject some of permissions the application is requesting.
        :param bool selective_stores: If the application is requesting the CanModifyStoreSettings permission and selectiveStores is set to true, this allows the user to only grant permissions to selected stores under the user's control.
        :param str redirect: The url to redirect to after the user consents, with the query parameters appended to it: permissions, user-id, api-key. If not specified, user is redirected to their API Key list.
        :param str application_identifier: If specified, BTCPay Server will check if there is an existing API key associated with the user that also has this application identifier, redirect host AND the permissions required match(takes selectiveStores and strict into account). `applicationIdentifier` is ignored if redirect is not specified.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['permissions', 'application_name', 'strict', 'selective_stores', 'redirect', 'application_identifier']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_keys_authorize_get" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'permissions' in params:
            query_params.append(('permissions', params['permissions']))  # noqa: E501
            collection_formats['permissions'] = 'multi'  # noqa: E501
        if 'application_name' in params:
            query_params.append(('applicationName', params['application_name']))  # noqa: E501
        if 'strict' in params:
            query_params.append(('strict', params['strict']))  # noqa: E501
        if 'selective_stores' in params:
            query_params.append(('selectiveStores', params['selective_stores']))  # noqa: E501
        if 'redirect' in params:
            query_params.append(('redirect', params['redirect']))  # noqa: E501
        if 'application_identifier' in params:
            query_params.append(('applicationIdentifier', params['application_identifier']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/html'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api-keys/authorize', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class GenerateOnChainWalletRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'existing_mnemonic': 'str',
        'passphrase': 'str',
        'account_number': 'float',
        'save_private_keys': 'bool',
        'import_keys_to_rpc': 'bool',
        'word_list': 'str',
        'word_count': 'float',
        'script_pub_key_type': 'str'
    }

    attribute_map = {
        'existing_mnemonic': 'existingMnemonic',
        'passphrase': 'passphrase',
        'account_number': 'accountNumber',
        'save_private_keys': 'savePrivateKeys',
        'import_keys_to_rpc': 'importKeysToRPC',
        'word_list': 'wordList',
        'word_count': 'wordCount',
        'script_pub_key_type': 'scriptPubKeyType'
    }

    def __init__(self, existing_mnemonic=None, passphrase=None, account_number=0, save_private_keys=False, import_keys_to_rpc=False, word_list='English', word_count=12, script_pub_key_type='Segwit'):  # noqa: E501
        """GenerateOnChainWalletRequest - a model defined in Swagger"""  # noqa: E501
        self._existing_mnemonic = None
        self._passphrase = None
        self._account_number = None
        self._save_private_keys = None
        self._import_keys_to_rpc = None
        self._word_list = None
        self._word_count = None
        self._script_pub_key_type = None
        self.discriminator = None
        if existing_mnemonic is not None:
            self.existing_mnemonic = existing_mnemonic
        if passphrase is not None:
            self.passphrase = passphrase
        if account_number is not None:
            self.account_number = account_number
        if save_private_keys is not None:
            self.save_private_keys = save_private_keys
        if import_keys_to_rpc is not None:
            self.import_keys_to_rpc = import_keys_to_rpc
        if word_list is not None:
            self.word_list = word_list
        if word_count is not None:
            self.word_count = word_count
        if script_pub_key_type is not None:
            self.script_pub_key_type = script_pub_key_type

    @property
    def existing_mnemonic(self):
        """Gets the existing_mnemonic of this GenerateOnChainWalletRequest.  # noqa: E501

        An existing BIP39 mnemonic seed to generate the wallet with  # noqa: E501

        :return: The existing_mnemonic of this GenerateOnChainWalletRequest.  # noqa: E501
        :rtype: str
        """
        return self._existing_mnemonic

    @existing_mnemonic.setter
    def existing_mnemonic(self, existing_mnemonic):
        """Sets the existing_mnemonic of this GenerateOnChainWalletRequest.

        An existing BIP39 mnemonic seed to generate the wallet with  # noqa: E501

        :param existing_mnemonic: The existing_mnemonic of this GenerateOnChainWalletRequest.  # noqa: E501
        :type: str
        """

        self._existing_mnemonic = existing_mnemonic

    @property
    def passphrase(self):
        """Gets the passphrase of this GenerateOnChainWalletRequest.  # noqa: E501

        A passphrase for the BIP39 mnemonic seed  # noqa: E501

        :return: The passphrase of this GenerateOnChainWalletRequest.  # noqa: E501
        :rtype: str
        """
        return self._passphrase

    @passphrase.setter
    def passphrase(self, passphrase):
        """Sets the passphrase of this GenerateOnChainWalletRequest.

        A passphrase for the BIP39 mnemonic seed  # noqa: E501

        :param passphrase: The passphrase of this GenerateOnChainWalletRequest.  # noqa: E501
        :type: str
        """

        self._passphrase = passphrase

    @property
    def account_number(self):
        """Gets the account_number of this GenerateOnChainWalletRequest.  # noqa: E501

        The account to derive from the BIP39 mnemonic seed  # noqa: E501

        :return: The account_number of this GenerateOnChainWalletRequest.  # noqa: E501
        :rtype: float
        """
        return self._account_number

    @account_number.setter
    def account_number(self, account_number):
        """Sets the account_number of this GenerateOnChainWalletRequest.

        The account to derive from the BIP39 mnemonic seed  # noqa: E501

        :param account_number: The account_number of this GenerateOnChainWalletRequest.  # noqa: E501
        :type: float
        """

        self._account_number = account_number

    @property
    def save_private_keys(self):
        """Gets the save_private_keys of this GenerateOnChainWalletRequest.  # noqa: E501

        Whether to store the seed inside BTCPay Server to enable some additional services. IF `false` AND `existingMnemonic` IS NOT SPECIFIED, BE SURE TO SECURELY STORE THE SEED IN THE RESPONSE!  # noqa: E501

        :return: The save_private_keys of this GenerateOnChainWalletRequest.  # noqa: E501
        :rtype: bool
        """
        return self._save_private_keys

    @save_private_keys.setter
    def save_private_keys(self, save_private_keys):
        """Sets the save_private_keys of this GenerateOnChainWalletRequest.

        Whether to store the seed inside BTCPay Server to enable some additional services. IF `false` AND `existingMnemonic` IS NOT SPECIFIED, BE SURE TO SECURELY STORE THE SEED IN THE RESPONSE!  # noqa: E501

        :param save_private_keys: The save_private_keys of this GenerateOnChainWalletRequest.  # noqa: E501
        :type: bool
        """

        self._save_private_keys = save_private_keys

    @property
    def import_keys_to_rpc(self):
        """Gets the import_keys_to_rpc of this GenerateOnChainWalletRequest.  # noqa: E501

        Whether to import all addresses generated via BTCPay Server into the underlying node wallet. (Private keys will also be imported if `savePrivateKeys` is set to true.  # noqa: E501

        :return: The import_keys_to_rpc of this GenerateOnChainWalletRequest.  # noqa: E501
        :rtype: bool
        """
        return self._import_keys_to_rpc

    @import_keys_to_rpc.setter
    def import_keys_to_rpc(self, import_keys_to_rpc):
        """Sets the import_keys_to_rpc of this GenerateOnChainWalletRequest.

        Whether to import all addresses generated via BTCPay Server into the underlying node wallet. (Private keys will also be imported if `savePrivateKeys` is set to true.  # noqa: E501

        :param import_keys_to_rpc: The import_keys_to_rpc of this GenerateOnChainWalletRequest.  # noqa: E501
        :type: bool
        """

        self._import_keys_to_rpc = import_keys_to_rpc

    @property
    def word_list(self):
        """Gets the word_list of this GenerateOnChainWalletRequest.  # noqa: E501

        If `existingMnemonic` is not set, a mnemonic is generated using the specified wordList.  # noqa: E501

        :return: The word_list of this GenerateOnChainWalletRequest.  # noqa: E501
        :rtype: str
        """
        return self._word_list

    @word_list.setter
    def word_list(self, word_list):
        """Sets the word_list of this GenerateOnChainWalletRequest.

        If `existingMnemonic` is not set, a mnemonic is generated using the specified wordList.  # noqa: E501

        :param word_list: The word_list of this GenerateOnChainWalletRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["English", "Japanese", "Spanish", "ChineseSimplified", "ChineseTraditional", "French", "PortugueseBrazil", "Czech"]  # noqa: E501
        if word_list not in allowed_values:
            raise ValueError(
                "Invalid value for `word_list` ({0}), must be one of {1}"  # noqa: E501
                .format(word_list, allowed_values)
            )

        self._word_list = word_list

    @property
    def word_count(self):
        """Gets the word_count of this GenerateOnChainWalletRequest.  # noqa: E501

        If `existingMnemonic` is not set, a mnemonic is generated using the specified wordCount.  # noqa: E501

        :return: The word_count of this GenerateOnChainWalletRequest.  # noqa: E501
        :rtype: float
        """
        return self._word_count

    @word_count.setter
    def word_count(self, word_count):
        """Sets the word_count of this GenerateOnChainWalletRequest.

        If `existingMnemonic` is not set, a mnemonic is generated using the specified wordCount.  # noqa: E501

        :param word_count: The word_count of this GenerateOnChainWalletRequest.  # noqa: E501
        :type: float
        """
        allowed_values = [12, 15, 18, 21, 24]  # noqa: E501
        if word_count not in allowed_values:
            raise ValueError(
                "Invalid value for `word_count` ({0}), must be one of {1}"  # noqa: E501
                .format(word_count, allowed_values)
            )

        self._word_count = word_count

    @property
    def script_pub_key_type(self):
        """Gets the script_pub_key_type of this GenerateOnChainWalletRequest.  # noqa: E501

        the type of wallet to generate  # noqa: E501

        :return: The script_pub_key_type of this GenerateOnChainWalletRequest.  # noqa: E501
        :rtype: str
        """
        return self._script_pub_key_type

    @script_pub_key_type.setter
    def script_pub_key_type(self, script_pub_key_type):
        """Sets the script_pub_key_type of this GenerateOnChainWalletRequest.

        the type of wallet to generate  # noqa: E501

        :param script_pub_key_type: The script_pub_key_type of this GenerateOnChainWalletRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["Legacy", "Segwit", "SegwitP2SH"]  # noqa: E501
        if script_pub_key_type not in allowed_values:
            raise ValueError(
                "Invalid value for `script_pub_key_type` ({0}), must be one of {1}"  # noqa: E501
                .format(script_pub_key_type, allowed_values)
            )

        self._script_pub_key_type = script_pub_key_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GenerateOnChainWalletRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GenerateOnChainWalletRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InvoicePaymentMethodDataModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'payment_method': 'str',
        'crypto_code': 'str',
        'destination': 'str',
        'payment_link': 'str',
        'rate': 'str',
        'payment_method_paid': 'str',
        'total_paid': 'str',
        'due': 'str',
        'amount': 'str',
        'network_fee': 'str',
        'payments': 'list[Payment]',
        'activated': 'bool',
        'additional_data': 'AnyOfInvoicePaymentMethodDataModelAdditionalData'
    }

    attribute_map = {
        'payment_method': 'paymentMethod',
        'crypto_code': 'cryptoCode',
        'destination': 'destination',
        'payment_link': 'paymentLink',
        'rate': 'rate',
        'payment_method_paid': 'paymentMethodPaid',
        'total_paid': 'totalPaid',
        'due': 'due',
        'amount': 'amount',
        'network_fee': 'networkFee',
        'payments': 'payments',
        'activated': 'activated',
        'additional_data': 'additionalData'
    }

    def __init__(self, payment_method=None, crypto_code=None, destination=None, payment_link=None, rate=None, payment_method_paid=None, total_paid=None, due=None, amount=None, network_fee=None, payments=None, activated=None, additional_data=None):  # noqa: E501
        """InvoicePaymentMethodDataModel - a model defined in Swagger"""  # noqa: E501
        self._payment_method = None
        self._crypto_code = None
        self._destination = None
        self._payment_link = None
        self._rate = None
        self._payment_method_paid = None
        self._total_paid = None
        self._due = None
        self._amount = None
        self._network_fee = None
        self._payments = None
        self._activated = None
        self._additional_data = None
        self.discriminator = None
        if payment_method is not None:
            self.payment_method = payment_method
        if crypto_code is not None:
            self.crypto_code = crypto_code
        if destination is not None:
            self.destination = destination
        if payment_link is not None:
            self.payment_link = payment_link
        if rate is not None:
            self.rate = rate
        if payment_method_paid is not None:
            self.payment_method_paid = payment_method_paid
        if total_paid is not None:
            self.total_paid = total_paid
        if due is not None:
            self.due = due
        if amount is not None:
            self.amount = amount
        if network_fee is not None:
            self.network_fee = network_fee
        if payments is not None:
            self.payments = payments
        if activated is not None:
            self.activated = activated
        if additional_data is not None:
            self.additional_data = additional_data

    @property
    def payment_method(self):
        """Gets the payment_method of this InvoicePaymentMethodDataModel.  # noqa: E501

        Payment method available for the invoice (e.g., \"BTC\" or \"BTC-LightningNetwork\" or \"BTC-LNURLPAY\")  # noqa: E501

        :return: The payment_method of this InvoicePaymentMethodDataModel.  # noqa: E501
        :rtype: str
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """Sets the payment_method of this InvoicePaymentMethodDataModel.

        Payment method available for the invoice (e.g., \"BTC\" or \"BTC-LightningNetwork\" or \"BTC-LNURLPAY\")  # noqa: E501

        :param payment_method: The payment_method of this InvoicePaymentMethodDataModel.  # noqa: E501
        :type: str
        """

        self._payment_method = payment_method

    @property
    def crypto_code(self):
        """Gets the crypto_code of this InvoicePaymentMethodDataModel.  # noqa: E501

        Crypto code of the payment method (e.g., \"BTC\" or \"LTC\")  # noqa: E501

        :return: The crypto_code of this InvoicePaymentMethodDataModel.  # noqa: E501
        :rtype: str
        """
        return self._crypto_code

    @crypto_code.setter
    def crypto_code(self, crypto_code):
        """Sets the crypto_code of this InvoicePaymentMethodDataModel.

        Crypto code of the payment method (e.g., \"BTC\" or \"LTC\")  # noqa: E501

        :param crypto_code: The crypto_code of this InvoicePaymentMethodDataModel.  # noqa: E501
        :type: str
        """

        self._crypto_code = crypto_code

    @property
    def destination(self):
        """Gets the destination of this InvoicePaymentMethodDataModel.  # noqa: E501

        The destination the payment must be made to  # noqa: E501

        :return: The destination of this InvoicePaymentMethodDataModel.  # noqa: E501
        :rtype: str
        """
        return self._destination

    @destination.setter
    def destination(self, destination):
        """Sets the destination of this InvoicePaymentMethodDataModel.

        The destination the payment must be made to  # noqa: E501

        :param destination: The destination of this InvoicePaymentMethodDataModel.  # noqa: E501
        :type: str
        """

        self._destination = destination

    @property
    def payment_link(self):
        """Gets the payment_link of this InvoicePaymentMethodDataModel.  # noqa: E501

        A payment link that helps pay to the payment destination  # noqa: E501

        :return: The payment_link of this InvoicePaymentMethodDataModel.  # noqa: E501
        :rtype: str
        """
        return self._payment_link

    @payment_link.setter
    def payment_link(self, payment_link):
        """Sets the payment_link of this InvoicePaymentMethodDataModel.

        A payment link that helps pay to the payment destination  # noqa: E501

        :param payment_link: The payment_link of this InvoicePaymentMethodDataModel.  # noqa: E501
        :type: str
        """

        self._payment_link = payment_link

    @property
    def rate(self):
        """Gets the rate of this InvoicePaymentMethodDataModel.  # noqa: E501

        The rate between this payment method's currency and the invoice currency  # noqa: E501

        :return: The rate of this InvoicePaymentMethodDataModel.  # noqa: E501
        :rtype: str
        """
        return self._rate

    @rate.setter
    def rate(self, rate):
        """Sets the rate of this InvoicePaymentMethodDataModel.

        The rate between this payment method's currency and the invoice currency  # noqa: E501

        :param rate: The rate of this InvoicePaymentMethodDataModel.  # noqa: E501
        :type: str
        """

        self._rate = rate

    @property
    def payment_method_paid(self):
        """Gets the payment_method_paid of this InvoicePaymentMethodDataModel.  # noqa: E501

        The amount paid by this payment method  # noqa: E501

        :return: The payment_method_paid of this InvoicePaymentMethodDataModel.  # noqa: E501
        :rtype: str
        """
        return self._payment_method_paid

    @payment_method_paid.setter
    def payment_method_paid(self, payment_method_paid):
        """Sets the payment_method_paid of this InvoicePaymentMethodDataModel.

        The amount paid by this payment method  # noqa: E501

        :param payment_method_paid: The payment_method_paid of this InvoicePaymentMethodDataModel.  # noqa: E501
        :type: str
        """

        self._payment_method_paid = payment_method_paid

    @property
    def total_paid(self):
        """Gets the total_paid of this InvoicePaymentMethodDataModel.  # noqa: E501

        The total amount paid by all payment methods to the invoice, converted to this payment method's currency  # noqa: E501

        :return: The total_paid of this InvoicePaymentMethodDataModel.  # noqa: E501
        :rtype: str
        """
        return self._total_paid

    @total_paid.setter
    def total_paid(self, total_paid):
        """Sets the total_paid of this InvoicePaymentMethodDataModel.

        The total amount paid by all payment methods to the invoice, converted to this payment method's currency  # noqa: E501

        :param total_paid: The total_paid of this InvoicePaymentMethodDataModel.  # noqa: E501
        :type: str
        """

        self._total_paid = total_paid

    @property
    def due(self):
        """Gets the due of this InvoicePaymentMethodDataModel.  # noqa: E501

        The total amount left to be paid, converted to this payment method's currency (will be negative if overpaid)  # noqa: E501

        :return: The due of this InvoicePaymentMethodDataModel.  # noqa: E501
        :rtype: str
        """
        return self._due

    @due.setter
    def due(self, due):
        """Sets the due of this InvoicePaymentMethodDataModel.

        The total amount left to be paid, converted to this payment method's currency (will be negative if overpaid)  # noqa: E501

        :param due: The due of this InvoicePaymentMethodDataModel.  # noqa: E501
        :type: str
        """

        self._due = due

    @property
    def amount(self):
        """Gets the amount of this InvoicePaymentMethodDataModel.  # noqa: E501

        The invoice amount, converted to this payment method's currency  # noqa: E501

        :return: The amount of this InvoicePaymentMethodDataModel.  # noqa: E501
        :rtype: str
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this InvoicePaymentMethodDataModel.

        The invoice amount, converted to this payment method's currency  # noqa: E501

        :param amount: The amount of this InvoicePaymentMethodDataModel.  # noqa: E501
        :type: str
        """

        self._amount = amount

    @property
    def network_fee(self):
        """Gets the network_fee of this InvoicePaymentMethodDataModel.  # noqa: E501

        The added merchant fee to pay for network costs of this payment method.  # noqa: E501

        :return: The network_fee of this InvoicePaymentMethodDataModel.  # noqa: E501
        :rtype: str
        """
        return self._network_fee

    @network_fee.setter
    def network_fee(self, network_fee):
        """Sets the network_fee of this InvoicePaymentMethodDataModel.

        The added merchant fee to pay for network costs of this payment method.  # noqa: E501

        :param network_fee: The network_fee of this InvoicePaymentMethodDataModel.  # noqa: E501
        :type: str
        """

        self._network_fee = network_fee

    @property
    def payments(self):
        """Gets the payments of this InvoicePaymentMethodDataModel.  # noqa: E501

        Payments made with this payment method.  # noqa: E501

        :return: The payments of this InvoicePaymentMethodDataModel.  # noqa: E501
        :rtype: list[Payment]
        """
        return self._payments

    @payments.setter
    def payments(self, payments):
        """Sets the payments of this InvoicePaymentMethodDataModel.

        Payments made with this payment method.  # noqa: E501

        :param payments: The payments of this InvoicePaymentMethodDataModel.  # noqa: E501
        :type: list[Payment]
        """

        self._payments = payments

    @property
    def activated(self):
        """Gets the activated of this InvoicePaymentMethodDataModel.  # noqa: E501

        If the payment method is activated (when lazy payments option is enabled  # noqa: E501

        :return: The activated of this InvoicePaymentMethodDataModel.  # noqa: E501
        :rtype: bool
        """
        return self._activated

    @activated.setter
    def activated(self, activated):
        """Sets the activated of this InvoicePaymentMethodDataModel.

        If the payment method is activated (when lazy payments option is enabled  # noqa: E501

        :param activated: The activated of this InvoicePaymentMethodDataModel.  # noqa: E501
        :type: bool
        """

        self._activated = activated

    @property
    def additional_data(self):
        """Gets the additional_data of this InvoicePaymentMethodDataModel.  # noqa: E501

        Additional data provided by the payment method.  # noqa: E501

        :return: The additional_data of this InvoicePaymentMethodDataModel.  # noqa: E501
        :rtype: AnyOfInvoicePaymentMethodDataModelAdditionalData
        """
        return self._additional_data

    @additional_data.setter
    def additional_data(self, additional_data):
        """Sets the additional_data of this InvoicePaymentMethodDataModel.

        Additional data provided by the payment method.  # noqa: E501

        :param additional_data: The additional_data of this InvoicePaymentMethodDataModel.  # noqa: E501
        :type: AnyOfInvoicePaymentMethodDataModelAdditionalData
        """

        self._additional_data = additional_data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InvoicePaymentMethodDataModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InvoicePaymentMethodDataModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
